Adam7Info

Struct Adam7Info 

pub struct Adam7Info { /* private fields */ }
Describes which stage of the Adam7 algorithm applies to a decoded row.

See also Reader::next_interlaced_row.

Implementations

Source

impl Adam7Info

pub fn new(pass: u8, line: u32, width: u32) -> Self

Creates a new Adam7Info. May panic if the arguments are out of range (e.g. if pass is 0 or greater than 8).

  • pass corresponds to a pass of the the Adam7 algorithm
  • line is the number of a line within a pass (starting with 0). For example, in an image of height 8, line can be beteween 0..4 in the 7th pass (those 4 interlaced rows correspond to 2nd, 4th, 6th, and 8th row of the full image).
  • width describes how many pixels are in a full row of the image. The bytes in each passline of the Adam7 are calculated from this number.

Note that in typical usage, Adam7Infos are returned by Reader::next_interlaced_row and there is no need to create them by calling Adam7Info::new. Adam7Info::new is nevertheless exposed as a public API, because it helps to provide self-contained example usage of expand_interlaced_row.