CodingIndependentCodePoints

Struct CodingIndependentCodePoints 

pub struct CodingIndependentCodePoints {
    pub color_primaries: u8,
    pub transfer_function: u8,
    pub matrix_coefficients: u8,
    pub is_video_full_range_image: bool,
}
Coding-independent code points (cICP) specify the color space (primaries), transfer function, matrix coefficients and scaling factor of the image using the code points specified in ITU-T-H.273.

See https://www.w3.org/TR/png-3/#cICP-chunk for more details.

Fields

color_primaries: u8

Id number of the color primaries defined in ITU-T-H.273 in “Table 2 - Interpretation of colour primaries (ColourPrimaries) value”.

transfer_function: u8

Id number of the transfer characteristics defined in ITU-T-H.273 in “Table 3 - Interpretation of transfer characteristics (TransferCharacteristics) value”.

matrix_coefficients: u8

Id number of the matrix coefficients defined in ITU-T-H.273 in “Table 4 - Interpretation of matrix coefficients (MatrixCoefficients) value”.

This field is included to faithfully replicate the base ITU-T-H.273 specification, but matrix coefficients will always be set to 0, because RGB is currently the only supported color mode in PNG.

is_video_full_range_image: bool

Whether the image is a full range image or a narrow range image.

This field is included to faithfully replicate the base ITU-T-H.273 specification, but it has limited practical application to PNG images, because narrow-range images are quite rare in practice.