ITXtChunk

Struct ITXtChunk 

pub struct ITXtChunk {
    pub keyword: String,
    pub compressed: bool,
    pub language_tag: String,
    pub translated_keyword: String,
    /* private fields */
}
Struct encoding an iTXt chunk

Fields

keyword: String

The keyword field. This needs to be between 1-79 bytes when encoded as Latin-1.

compressed: bool

Indicates whether the text will be (or was) compressed in the PNG.

language_tag: String

A hyphen separated list of languages that the keyword is translated to. This is ASCII-7 encoded.

translated_keyword: String

Translated keyword. This is UTF-8 encoded.

Implementations

Source

impl ITXtChunk

pub fn new(keyword: impl Into<String>, text: impl Into<String>) -> Self

Constructs a new iTXt chunk. Leaves all but keyword and text to default values.

pub fn decompress_text(&mut self) -> Result<(), DecodingError>

Decompresses the inner text, mutating its own state. Can only handle decompressed text up to DECOMPRESSION_LIMIT bytes.

pub fn decompress_text_with_limit( &mut self, limit: usize, ) -> Result<(), DecodingError>

Decompresses the inner text, mutating its own state. Can only handle decompressed text up to limit bytes.

pub fn get_text(&self) -> Result<String, DecodingError>

Decompresses the inner text, and returns it as a String. If decompression takes more than 2 MiB, try decompress_text_with_limit followed by this method.

pub fn compress_text(&mut self) -> Result<(), EncodingError>

Compresses the inner text, mutating its own state.