Struct png::FrameControl [−][src]
pub struct FrameControl {
pub sequence_number: u32,
pub width: u32,
pub height: u32,
pub x_offset: u32,
pub y_offset: u32,
pub delay_num: u16,
pub delay_den: u16,
pub dispose_op: u8,
pub blend_op: u8,
}Expand description
Frame control information
Fields
sequence_number: u32Sequence number of the animation chunk, starting from 0
width: u32Width of the following frame
height: u32Height of the following frame
x_offset: u32X position at which to render the following frame
y_offset: u32Y position at which to render the following frame
delay_num: u16Frame delay fraction numerator
delay_den: u16Frame delay fraction denominator
dispose_op: u8Type of frame area disposal to be done after rendering this frame
blend_op: u8Type of frame area rendering for this frame